Installation — openDAQ 0.2.0 documentation

# Installation

You will need Administrator rights (root access) to install this package system-wide.

Using pip:

    $ pip install opendaq

# Development

You will need some additional development tools if you want to collaborate with this project. They can be installed at once using pip:

    $ pip install -r requirements-dev.txt

Then you can install the package in development mode:

    $ python setup.py develop